function nY = clamp(Y)
% CLAMP		rescales the n row vectors of the matrix Y to unit length. If a row vector a priori has length zero, a
% random choice is made.
%
%	Usages:
%	nY = CLAMP(Y)
%
%	Y is expected to satisfy diag(Y*Y')=I to order epsilon
%	nY will satisfy Y'*Y = I 
%

    [n,d]=size(Y);    
    
    % set correct dimensions
    nY=Y;
        
    for i=1:n
        normY=norm( Y(i,:), 'fro' );
        if normY >0.0
            nY(i,:) = Y(i,:) / normY;
        else
            nY(i,:) = zeros(1,d); nY(i,1)=1.0;
        end
    end
