function Y = guess( C, d, varargin )
%guess Y=guess(C,d)
% usages:
%   Y=guess(C,d)
%   Y=guess(C,d,W)
% Finds an initial feasible point Y to the problem min norm(R-X*X','fro')^2 subject to diag(X*X')=I with X an nxd
% matrix, n=size(C,1).
% If W is provided the factorisation is performed with respect to the matrix norm induced by the positive semidefinite matrix W
% the 'default' for W is I

    % dim
    n=size(C,1);
        
    % is a weights matrix provided?
    if length( varargin ) == 1
        W=varargin{1};
    else
        W=eye(n);
    end
    
    % square root of W
    sqrW = W^0.5;
    isqrW = inv(sqrW);

    % project onto rank d
    [V,L] = svdplus( sqrW*C*sqrW );
    L=max( L, zeros(n) );
    Y = isqrW*V(:,1:d)*sqrt(L(1:d,1:d));
        
    % rescale Y
    Y = clamp( Y );
    