function [Xn, Fn] = major( R, d, tol )
%MAJOR Majorisation algorithm for rank reduction of correlation matrices
%  Majorization algorithm for minimization of F(X)=norm(R-X*X','fro')^2 such that diag(X*X')=I with X an nxd matrix with n=size(R,1)=size(R,2). Convergence is
%  guaranteed if the matrix R is symmetric and has unit diagonal. Tolerance is the convergence criterion for the
%  norm of the gradient 4*Psi*X with Psi = Y*Y'-R.
%  usage [Xn, Fn] = major( R, d, tol )

    % first obtain initial guess
    X=guess(R,d);
    
    % initial gradient, obj value
    mygrad=grad( X, R );
    normgrad=norm(mygrad,'fro');
    Fn=F(X,R);
    
    % output
    n=0;
    disp(sprintf('%s\t%s\t\t%s','iter','|grad|','F(X)'));
	disp(sprintf('%d\t%e\t%e\t%s',n,normgrad,Fn));
    
    % dimension
    N=size(R,1);

    while normgrad>tol
                
        for i=1:N

            % calculate B and its largest eigenvalue lambda
            B=X'*X-X(i,:)'*X(i,:);
            lambda= max(eig(B));
            
            z=(lambda-1.0)*X(i,:)-(B*X(i,:)')'+R(i,:)*X;
            X(i,:)=z/norm(z);
        
        end
        
        % gradient, obj value
        n=n+1;
        mygrad=grad( X, R );
        normgrad=norm(mygrad,'fro');
        Fn=F(X,R);
        
        % output
        disp(sprintf('%d\t%e\t%e\t%s',n,normgrad,Fn));
        
    end
    
Xn=X;
